@@ -3,7 +3,7 @@ package Basic::Coercion::XS;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load("Basic::Coercion::XS", $VERSION);
@@ -12,11 +12,11 @@ __END__
 
 =head1 NAME
 
-Basic::Coercion::XS - The great new Basic::Coercion::XS!
+Basic::Coercion::XS - basic coercions
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
